@@ -458,7 +458,7 @@ class Distributive(object):
                               PartitionDistributive:"partdir"}
                 extname = mapExtName.get(distr.__class__,"")
                 image = distr.convertToDirectory()
-            except Exception,e:
+            except Exception as e:
                 if distr:
                     distr.close()
                 return {}.copy()
