@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,9 +14,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from calculate.install.datavars import __version__,__app__
-from calculate.lib.datavars import ReadonlyVariable
-
 import action
 import disk
 import locale
@@ -30,15 +27,3 @@ import lvm
 import autopartition
 
 section = "install"
-
-class VariableClName(ReadonlyVariable):
-    """
-    Package name
-    """
-    value = __app__
-
-class VariableClVer(ReadonlyVariable):
-    """
-    Package version
-    """
-    value = __version__
