@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ from calculate.lib.utils.device import (getUdevDeviceInfo,getDeviceType,
                         humanreadableSize,refreshUdev)
 from calculate.lib.utils.files import (listDirectory,pathJoin,readFile,FStab,
                                         readLinesFile,process,getProgPath)
-from calculate.install.cl_distr import PartitionDistributive
+from calculate.install.distr import PartitionDistributive
 from calculate.install.fs_manager import FileSystemManager
 from itertools import *
 import operator
@@ -509,31 +509,33 @@ class VariableClAutopartitionScheme(AutopartitionHelper,Variable,AutoPartition):
                 ("data",_("/var/calculate partition")),
                 ("home",_("Mount /var/calculate/home to /home")),
                 ("boot",_("Separate boot partition")),
-                ("uefi",_("Use UEFI bootloader")),
+                ("uefi",_("Use the UEFI bootloader")),
                 ("lvm",_("Use LVM")),
-                ("grub",_("Create bios_grub partition")),
+                ("grub",_("Create the bios_grub partition")),
                ]
 
     def check(self,value):
         if "uefi" in value:
             if self.Get('os_uefi_set') == 'off':
                 raise VariableError(
-                  _("System must be loaded in UEFI for using this bootloader"))
+                  _("Your system must be loaded in UEFI for using this "
+                    "bootloader"))
             if self.Get('os_install_arch_machine') != 'x86_64':
                 raise VariableError(
                     _("Architecture of the target system must be x86_64 "
-                      "for using UEFI bootloader"))
+                      "for using the UEFI bootloader"))
             if self.Get('cl_autopartition_table') != 'gpt':
                 raise VariableError(
-                    _("Partition table must be GPT for using UEFI bootloader"))
+                    _("The partition table must be GPT for using "
+                      "UEFI bootloader"))
         else:
             if self.Get('cl_autopartition_table') == 'gpt' and not "grub" in value:
                 raise VariableError(
-                    _("For grub installation need bios_grub partition"))
+                    _("A 'bios_grub' partition is needed to install grub"))
         if "grub" in value:
             if self.Get('cl_autopartition_table') != 'gpt':
                 raise VariableError(
-                    _("Partition table must be GPT for bios_grub partition"))
+                    _("The bios_grub partition need the partition table to be GPT"))
 
 
 class VariableClAutopartitionRootSize(AutopartitionHelper,Variable):
@@ -611,7 +613,8 @@ class VariableClAutopartitionDiskData(ReadonlyTableVariable):
               'cl_autopartition_disk_mount',
               'cl_autopartition_disk_format',
               'cl_autopartition_disk_size',
-              'cl_autopartition_disk_part']
+              'cl_autopartition_disk_part',
+              'cl_autopartition_disk_scheme']
 
 class VariableClAutopartitionBiosGrubSet(ReadonlyVariable):
     """
@@ -713,6 +716,27 @@ class VariableClAutopartitionDiskDev(ReadonlyVariable,AutopartitionHelper):
                 return res
         return []
 
+class VariableClAutopartitionDiskScheme(ReadonlyVariable,AutopartitionHelper):
+    """
+    Назначение раздела относительно схемы авторазметки
+    """
+    type = "list"
+
+    def generateScheme(self,scheme):
+        """
+        Generate mount points for automount scheme
+        """
+        for line in self.deviceOpts(scheme):
+            yield line
+
+    def get(self):
+        if self.Get('cl_autopartition_set') == "on":
+            scheme = self.getAutopartitionScheme()
+            device = self.Get('cl_autopartition_device')
+            if device:
+                return list(self.generateScheme(scheme))
+        return []
+
 class VariableClAutopartitionDiskMount(ReadonlyVariable,AutopartitionHelper):
     """
     Autopartition mount points
