@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ from calculate.lib.utils.device import (getUdevDeviceInfo,getDeviceType,
                         getUUIDDict,getCommonDeviceName)
 from calculate.lib.utils.files import (listDirectory,pathJoin,readFile,FStab,
                                        isMount)
-from calculate.install.cl_distr import PartitionDistributive
+from calculate.install.distr import PartitionDistributive
 from calculate.install.fs_manager import FileSystemManager
 
 from calculate.lib.cl_lang import setLocalTranslate
@@ -910,7 +910,7 @@ class VariableOsLocationDest(LocationHelper,Variable):
                                where='os_install_disk_type',
                                ne='disk-partition')
         if set(efiDisks) & set(wrongPart):
-            raise VariableError(_("UEFI partition must be partition on disk"))
+            raise VariableError(_("UEFI partition must be a disk partition"))
         ###############################
         # check cross bind mount points
         ###############################
@@ -1701,7 +1701,7 @@ class VariableOsInstallMbr(LocationHelper,Variable):
                                         where='os_disk_id',eq='EF02')
                 if not mbrDisk in bios_grub:
                     raise VariableError(
-                        _("Disk %s must has 'bios_grub' partition")%mbrDisk)
+                        _("Disk %s must have a 'bios_grub' partition")%mbrDisk)
         if value:
             if self.Get('os_grub2_path'):
                 self.checkForGrub2()
@@ -1749,7 +1749,7 @@ class VariableOsInstallMbr(LocationHelper,Variable):
         Network setting up unavailable for flash installation
         """
         if self.Get('os_install_uefi_set') == "on":
-            return _("MBR is not using with UEFI bootloader")
+            return _("MBR is not used with the UEFI bootloader")
         if self.Get('cl_autopartition_set') == "on":
             return \
                 _("The layout is not available with autopartitioning")
