@@ -35,6 +35,7 @@ from calculate.lib.utils.portage import isPkgInstalled
 from operator import itemgetter
 from itertools import *
 import hashlib
+from calculate.install.distr import DistributiveError
 
 class NetHelper:
     """
@@ -154,6 +155,13 @@ class VariableOsInstallNetData(NetHelper,TableVariable):
         self.help = _("Network interface, DHCP or IP address and network mask "
                       "(example: %s)")%" --iface eth0:192.168.1.1:24"
 
+    def raiseReadonlyIndexError(self,fieldname="",variablename="",
+                                value=""):
+        """
+        Behavior on change readonly index
+        """
+        raise VariableError(_("Network interface %s not found")%value)
+
 class VariableOsInstallNetHostname(NetHelper,Variable):
     """
     Computer hostname
@@ -649,11 +657,14 @@ class VariableOsInstallNetConfAvailable(NetHelper,Variable):
         image = self.Get('cl_image')
         if image:
             with image as distr:
-                distrPath = image.getDirectory()
-                return map(itemgetter(0,2),
-                       filter(lambda x:not x[1] or isPkgInstalled(x[1],
-                                           prefix=distrPath),
-                       mapNetConf))
+                try:
+                    distrPath = image.getDirectory()
+                    return map(itemgetter(0,2),
+                           filter(lambda x:not x[1] or isPkgInstalled(x[1],
+                                               prefix=distrPath),
+                           mapNetConf))
+                except DistributiveError as e:
+                    pass
         return sorted(map(itemgetter(0,2),mapNetConf[-1:]),key=itemgetter(1))
 
 class VariableOsInstallNetConf(NetHelper,Variable):
