@@ -25,7 +25,7 @@ from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile,getProgPath,process,
     readLinesFile)
 from calculate.lib.utils.common import getPasswdUsers,getUserGroups,getGroups
-from calculate.lib.utils.common import getValueFromConfig
+from calculate.lib.utils.common import getValueFromConfig,getValueFromCmdLine
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
 from crypt import crypt
@@ -170,8 +170,8 @@ class VariableClInstallHomeCryptSet(UserHelper,Variable):
     untrusted = True
 
     def init(self):
-        self.help = _("crypt user profiles")
-        self.label = _("Crypt user profiles")
+        self.help = _("encrypt user profiles")
+        self.label = _("Encrypt user profiles")
 
     def get(self):
         return ("off" if self.Get('cl_autologin')
@@ -180,7 +180,7 @@ class VariableClInstallHomeCryptSet(UserHelper,Variable):
     def check(self,value):
         if value == "on" and self.Get('cl_autologin'):
             raise VariableError(
-                _("Crypt user profile uncompatible with autologin"))
+                _("User profile encryption is uncompatible with autologin"))
 
 class VariableClMigrateData(UserHelper,TableVariable):
     """
@@ -204,7 +204,7 @@ class VariableClMigrateUser(UserHelper,Variable):
     type = 'list'
 
     def init(self):
-        self.label = _("Login")
+        self.label = _("Users")
 
     def get(self):
         """
@@ -319,7 +319,10 @@ class VariableClAutologin(UserHelper,Variable):
 
     def get(self):
         # autologin enable for livecd and all install type CMC
-        if self.Get('os_install_root_type') == "livecd" or \
+        cmdDomainSet = (getValueFromCmdLine("calculate","domain_pw") or 
+                        getValueFromCmdLine("calculate","domain") or "")
+        if (not cmdDomainSet and 
+            self.Get('os_install_root_type') == "livecd" ) or \
             self.Get('os_install_linux_shortname') == "CMC":
             nonRootUsers = filter(lambda x: x != "root",
                            self.Get('cl_migrate_user'))
@@ -561,12 +564,13 @@ class VariableClLive(Variable):
         self.label = _("Configure dynamic options only")
         self.help = _("configure dynamic options only")
 
-class VariableOsInstallPxe(ReadonlyVariable):
+class VariableOsInstallPxe(Variable):
     """
     Installation for PXE loading
     """
     type = "boot"
     value = "off"
+    untrusted = True
 
     def check(self,value):
         if value == "on":
@@ -745,7 +749,7 @@ class VariableOsAudioDefault(Variable):
 
     def init(self):
         self.label = _("Default audio card")
-        self.help = _("set default audio card")
+        self.help = _("set the default audio")
 
     def get(self):
         defaultCardRe = re.compile('defaults.ctl.card\s+(\d+)')
@@ -766,6 +770,6 @@ class VariableOsAudioDefault(Variable):
         """
         Audio setting up unavailable for flash installation
         """
-        if self.Get('os_install_root_type') != 'flash':
+        if self.Get('os_install_root_type') == 'flash':
             return _("Audio configuration unavailable for Flash install")
         return ""
